@@ -9,17 +9,17 @@
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2, or (at your option)
-# any later version.
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 import os
 
@@ -47,7 +47,13 @@ class EngineFactory(IBus.Factory):
         self.__id = 0
         self.__config = self.__bus.get_config()
 
-        self.__config.connect('value-changed', self.__config_value_changed_cb)
+        if self.__config != None:
+            self.__config.connect('value-changed',
+                                  self.__config_value_changed_cb)
+        else:
+            print >> sys.stderr, \
+                'ibus-config is not running or bus address is not correct.'
+
         bus.get_connection().signal_subscribe('org.freedesktop.DBus',
                                               'org.freedesktop.DBus',
                                               'NameOwnerChanged',
